diff -pruN 0.3.4-2/debian/changelog 0.3.6-1/debian/changelog
--- 0.3.4-2/debian/changelog	2020-08-04 18:02:34.000000000 +0000
+++ 0.3.6-1/debian/changelog	2020-11-12 11:51:55.000000000 +0000
@@ -1,3 +1,9 @@
+castxml (0.3.6-1) unstable; urgency=medium
+
+  * New upstream version 0.3.6
+
+ -- Gert Wollny <gewo@debian.org>  Thu, 12 Nov 2020 12:51:55 +0100
+
 castxml (0.3.4-2) unstable; urgency=medium
 
   * Team upload
diff -pruN 0.3.4-2/README.rst 0.3.6-1/README.rst
--- 0.3.4-2/README.rst	2020-04-27 14:13:56.000000000 +0000
+++ 0.3.6-1/README.rst	2020-08-21 14:29:03.000000000 +0000
@@ -46,7 +46,8 @@ To build CastXML from source, first obta
 * `LLVM/Clang`_ compiler SDK install tree built using the C++ compiler.
   This version of CastXML has been tested with LLVM/Clang
 
-  - Git master as of 2020-02-13 (``6c73246179``)
+  - Release ``11.0``
+  - Git master as of 2020-07-13 (``3d0b76022d``)
   - Release ``10.0``
   - Release ``9.0``
   - Release ``8.0``
diff -pruN 0.3.4-2/src/Detect.cxx 0.3.6-1/src/Detect.cxx
--- 0.3.4-2/src/Detect.cxx	2020-04-27 14:13:56.000000000 +0000
+++ 0.3.6-1/src/Detect.cxx	2020-08-21 14:29:03.000000000 +0000
@@ -91,6 +91,9 @@ static void setTriple(Options& opts)
   } else if (pd.find("#define __i386__ 1") != pd.npos ||
              pd.find("#define _M_IX86 ") != pd.npos) {
     triple.setArchName("i386");
+  } else if (pd.find("#define __aarch64__ 1") != pd.npos ||
+             pd.find("#define _M_ARM64 ") != pd.npos) {
+    triple.setArchName("aarch64");
   }
   if (pd.find("#define _WIN32 1") != pd.npos) {
     triple.setVendorName("pc");
@@ -105,6 +108,16 @@ static void setTriple(Options& opts)
   opts.Triple = triple.getTriple();
 }
 
+static bool isBuiltinIncludeDir(std::string const& inc)
+{
+  // FIXME: Intrinsics headers are platform-specific.
+  // Is there a better way to detect this directory?
+  return (llvm::sys::fs::exists(inc + "/emmintrin.h")   // x86_64
+          || llvm::sys::fs::exists(inc + "/altivec.h")  // ppc64
+          || llvm::sys::fs::exists(inc + "/arm_neon.h") // aarch64
+  );
+}
+
 static bool detectCC_GNU(const char* const* argBeg, const char* const* argEnd,
                          Options& opts, const char* id, const char* ext)
 {
@@ -146,11 +159,7 @@ static bool detectCC_GNU(const char* con
                      fwImplicitSuffix));
             }
             // Replace the compiler builtin include directory with ours.
-            if (!fw &&
-                // FIXME: Intrinsics headers are platform-specific.
-                // Is there a better way to detect this directory?
-                (llvm::sys::fs::exists(inc + "/emmintrin.h") ||
-                 llvm::sys::fs::exists(inc + "/altivec.h"))) {
+            if (!fw && isBuiltinIncludeDir(inc)) {
               inc = getClangBuiltinIncludeDir();
             }
             opts.Includes.push_back(Options::Include(inc, fw));
diff -pruN 0.3.4-2/src/Output.cxx 0.3.6-1/src/Output.cxx
--- 0.3.4-2/src/Output.cxx	2020-04-27 14:13:56.000000000 +0000
+++ 0.3.6-1/src/Output.cxx	2020-08-21 14:29:03.000000000 +0000
@@ -31,6 +31,8 @@
 #include "clang/AST/Mangle.h"
 #include "clang/AST/PrettyPrinter.h"
 #include "clang/AST/RecordLayout.h"
+#include "clang/Basic/FileManager.h"
+#include "clang/Basic/SourceLocation.h"
 #include "clang/Basic/Specifiers.h"
 #include "clang/Basic/TargetInfo.h"
 #include "clang/Frontend/CompilerInstance.h"
diff -pruN 0.3.4-2/src/Version.cmake 0.3.6-1/src/Version.cmake
--- 0.3.4-2/src/Version.cmake	2020-04-27 14:13:56.000000000 +0000
+++ 0.3.6-1/src/Version.cmake	2020-08-21 14:29:03.000000000 +0000
@@ -1,7 +1,7 @@
 # CastXML version number components.
 set(CastXML_VERSION_MAJOR 0)
 set(CastXML_VERSION_MINOR 3)
-set(CastXML_VERSION_PATCH 4)
+set(CastXML_VERSION_PATCH 6)
 set(CastXML_VERSION_RC 0)
 set(CastXML_VERSION_IS_DIRTY 0)
 
@@ -13,7 +13,7 @@ if(CastXML_VERSION_RC)
 endif()
 
 # If this source was exported by 'git archive', use its commit info.
-set(git_info "3dc416a CastXML 0.3.4")
+set(git_info "902ac16 CastXML 0.3.6")
 
 # Otherwise, try to identify the current development source version.
 if(NOT git_info MATCHES "^([0-9a-f][0-9a-f][0-9a-f][0-9a-f][0-9a-f][0-9a-f]?[0-9a-f]?)[0-9a-f]* "
diff -pruN 0.3.4-2/test/CMakeLists.txt 0.3.6-1/test/CMakeLists.txt
--- 0.3.4-2/test/CMakeLists.txt	2020-04-27 14:13:56.000000000 +0000
+++ 0.3.6-1/test/CMakeLists.txt	2020-08-21 14:29:03.000000000 +0000
@@ -344,6 +344,7 @@ castxml_test_cmd(cc-gnu-bad-cmd --castxm
 castxml_test_cmd(cc-gnu-src-c-E --castxml-cc-gnu $<TARGET_FILE:cc-gnu> ${empty_c} -E -dM)
 castxml_test_cmd(cc-gnu-src-cxx-E --castxml-cc-gnu $<TARGET_FILE:cc-gnu> ${empty_cxx} -E -dM)
 castxml_test_cmd(cc-gnu-src-cxx-cmd --castxml-cc-gnu $<TARGET_FILE:cc-gnu> ${empty_cxx} "-###")
+castxml_test_cmd(cc-gnu-tgt-aarch64 --castxml-cc-gnu "(" $<TARGET_FILE:cc-gnu> --cc-define=__aarch64__ ")" ${empty_cxx} "-###")
 castxml_test_cmd(cc-gnu-tgt-amd64 --castxml-cc-gnu "(" $<TARGET_FILE:cc-gnu> --cc-define=__amd64__ ")" ${empty_cxx} "-###")
 castxml_test_cmd(cc-gnu-tgt-explicit --castxml-cc-gnu "(" $<TARGET_FILE:cc-gnu> ")" -target explicit-target-triple ${empty_cxx} "-###")
 castxml_test_cmd(cc-gnu-tgt-i386 --castxml-cc-gnu "(" $<TARGET_FILE:cc-gnu> --cc-define=__i386__ ")" ${empty_cxx} "-###")
@@ -386,6 +387,7 @@ castxml_test_cmd(cc-msvc-bad-cmd --castx
 castxml_test_cmd(cc-msvc-src-c-E --castxml-cc-msvc $<TARGET_FILE:cc-msvc> ${empty_c} -E -dM)
 castxml_test_cmd(cc-msvc-src-cxx-E --castxml-cc-msvc $<TARGET_FILE:cc-msvc> ${empty_cxx} -E -dM)
 castxml_test_cmd(cc-msvc-src-cxx-cmd --castxml-cc-msvc $<TARGET_FILE:cc-msvc> ${empty_cxx} "-###")
+castxml_test_cmd(cc-msvc-tgt-aarch64 --castxml-cc-msvc "(" $<TARGET_FILE:cc-msvc> --cc-define=_M_ARM64 ")" ${empty_cxx} "-###")
 castxml_test_cmd(cc-msvc-tgt-amd64 --castxml-cc-msvc "(" $<TARGET_FILE:cc-msvc> --cc-define=_M_AMD64 ")" ${empty_cxx} "-###")
 castxml_test_cmd(cc-msvc-tgt-explicit --castxml-cc-msvc "(" $<TARGET_FILE:cc-msvc> ")" -target explicit-target-triple ${empty_cxx} "-###")
 castxml_test_cmd(cc-msvc-tgt-i386 --castxml-cc-msvc "(" $<TARGET_FILE:cc-msvc> --cc-define=_M_IX86 ")" ${empty_cxx} "-###")
diff -pruN 0.3.4-2/test/expect/castxml1.any.Field.xml.txt 0.3.6-1/test/expect/castxml1.any.Field.xml.txt
--- 0.3.4-2/test/expect/castxml1.any.Field.xml.txt	2020-04-27 14:13:56.000000000 +0000
+++ 0.3.6-1/test/expect/castxml1.any.Field.xml.txt	2020-08-21 14:29:03.000000000 +0000
@@ -4,14 +4,14 @@
   <Field id="_3" name="field" type="_10" context="_1" access="private" location="f1:3" file="f1" line="3" offset="0"/>
   <Field id="_4" name="bit_field" type="_11" bits="2" context="_1" access="private" location="f1:4" file="f1" line="4" offset="32"/>
   <Field id="_5" name="mutable_field" type="_10" context="_1" access="private" location="f1:5" file="f1" line="5" offset="64" mutable="1"/>
-  <Constructor id="_6" name="start" context="_1" access="public" location="f1:1" file="f1" line="1" inline="1" artificial="1"( throw="")?>
-    <Argument type="_12" location="f1:1" file="f1" line="1"/>
+  <Constructor id="_6" name="start" context="_1" access="public" location="f1:7" file="f1" line="7">
+    <Argument type="_12" location="f1:7" file="f1" line="7"/>
   </Constructor>
-  <OperatorMethod id="_7" name="=" returns="_13" context="_1" access="public" location="f1:1" file="f1" line="1" inline="1" artificial="1"( throw="")? mangled="[^"]+">
-    <Argument type="_12" location="f1:1" file="f1" line="1"/>
+  <OperatorMethod id="_7" name="=" returns="_13" context="_1" access="public" location="f1:8" file="f1" line="8" mangled="[^"]+">
+    <Argument type="_12" location="f1:8" file="f1" line="8"/>
   </OperatorMethod>
-  <Constructor id="_8" name="start" context="_1" access="public" location="f1:1" file="f1" line="1" inline="1" artificial="1"( throw="")?/>
-  <Destructor id="_9" name="start" context="_1" access="public" location="f1:1" file="f1" line="1" inline="1" artificial="1"( throw="")?/>
+  <Constructor id="_8" name="start" context="_1" access="public" location="f1:9" file="f1" line="9"/>
+  <Destructor id="_9" name="start" context="_1" access="public" location="f1:10" file="f1" line="10"/>
   <FundamentalType id="_10" name="int" size="[0-9]+" align="[0-9]+"/>
   <FundamentalType id="_11" name="unsigned int" size="[0-9]+" align="[0-9]+"/>
   <ReferenceType id="_12" type="_1c" size="[0-9]+" align="[0-9]+"/>
diff -pruN 0.3.4-2/test/expect/cmd.cc-gnu-tgt-aarch64.stderr.txt 0.3.6-1/test/expect/cmd.cc-gnu-tgt-aarch64.stderr.txt
--- 0.3.4-2/test/expect/cmd.cc-gnu-tgt-aarch64.stderr.txt	1970-01-01 00:00:00.000000000 +0000
+++ 0.3.6-1/test/expect/cmd.cc-gnu-tgt-aarch64.stderr.txt	2020-08-21 14:29:03.000000000 +0000
@@ -0,0 +1,3 @@
+Target: aarch64-[^
+]+
+.
diff -pruN 0.3.4-2/test/expect/cmd.cc-msvc-tgt-aarch64.stderr.txt 0.3.6-1/test/expect/cmd.cc-msvc-tgt-aarch64.stderr.txt
--- 0.3.4-2/test/expect/cmd.cc-msvc-tgt-aarch64.stderr.txt	1970-01-01 00:00:00.000000000 +0000
+++ 0.3.6-1/test/expect/cmd.cc-msvc-tgt-aarch64.stderr.txt	2020-08-21 14:29:03.000000000 +0000
@@ -0,0 +1,4 @@
+Target: aarch64-[^
+]+-msvc[^
+]*
+.
diff -pruN 0.3.4-2/test/expect/gccxml.any.Field.xml.txt 0.3.6-1/test/expect/gccxml.any.Field.xml.txt
--- 0.3.4-2/test/expect/gccxml.any.Field.xml.txt	2020-04-27 14:13:56.000000000 +0000
+++ 0.3.6-1/test/expect/gccxml.any.Field.xml.txt	2020-08-21 14:29:03.000000000 +0000
@@ -4,14 +4,14 @@
   <Field id="_3" name="field" type="_10" context="_1" access="private" location="f1:3" file="f1" line="3" offset="0"/>
   <Field id="_4" name="bit_field" type="_11" bits="2" context="_1" access="private" location="f1:4" file="f1" line="4" offset="32"/>
   <Field id="_5" name="mutable_field" type="_10" context="_1" access="private" location="f1:5" file="f1" line="5" offset="64" mutable="1"/>
-  <Constructor id="_6" name="start" context="_1" access="public" location="f1:1" file="f1" line="1" inline="1" artificial="1"( throw="")?>
-    <Argument type="_12" location="f1:1" file="f1" line="1"/>
+  <Constructor id="_6" name="start" context="_1" access="public" location="f1:7" file="f1" line="7">
+    <Argument type="_12" location="f1:7" file="f1" line="7"/>
   </Constructor>
-  <OperatorMethod id="_7" name="=" returns="_13" context="_1" access="public" location="f1:1" file="f1" line="1" inline="1" artificial="1"( throw="")? mangled="[^"]+">
-    <Argument type="_12" location="f1:1" file="f1" line="1"/>
+  <OperatorMethod id="_7" name="=" returns="_13" context="_1" access="public" location="f1:8" file="f1" line="8" mangled="[^"]+">
+    <Argument type="_12" location="f1:8" file="f1" line="8"/>
   </OperatorMethod>
-  <Constructor id="_8" name="start" context="_1" access="public" location="f1:1" file="f1" line="1" inline="1" artificial="1"( throw="")?/>
-  <Destructor id="_9" name="start" context="_1" access="public" location="f1:1" file="f1" line="1" inline="1" artificial="1"( throw="")?/>
+  <Constructor id="_8" name="start" context="_1" access="public" location="f1:9" file="f1" line="9"/>
+  <Destructor id="_9" name="start" context="_1" access="public" location="f1:10" file="f1" line="10"/>
   <FundamentalType id="_10" name="int" size="[0-9]+" align="[0-9]+"/>
   <FundamentalType id="_11" name="unsigned int" size="[0-9]+" align="[0-9]+"/>
   <ReferenceType id="_12" type="_1c" size="[0-9]+" align="[0-9]+"/>
diff -pruN 0.3.4-2/test/input/Field.cxx 0.3.6-1/test/input/Field.cxx
--- 0.3.4-2/test/input/Field.cxx	2020-04-27 14:13:56.000000000 +0000
+++ 0.3.6-1/test/input/Field.cxx	2020-08-21 14:29:03.000000000 +0000
@@ -3,4 +3,9 @@ class start
   int field;
   unsigned bit_field : 2;
   mutable int mutable_field;
+public:
+  start(start const&);
+  start& operator=(start const&);
+  start();
+  ~start();
 };
